'use strict';

var vue = require('vue');

const validFlip = [
    'horizontal',
    'vertical',
    'both',
];
const validPull = [
    'right',
    'left',
];

var script = vue.defineComponent({
  props: {
    icon: {
      type: Object,
      required: true
    },
    fw: Boolean,
    flip: {
      type: String,
      validator: function validator(value) {
        return validFlip.indexOf(value) >= 0;
      }
    },
    pull: {
      type: String,
      validator: function validator(value) {
        return validPull.indexOf(value) >= 0;
      }
    },
    rotate: {
      type: [Number, String],
      validator: function validator(value) {
        return /^[-\d.]+$/.test("" + value);
      }
    },
    size: {
      type: String,
      validator: function validator(value) {
        return /^(lg|xs|sm|([\d.]+)x)$/.test(value);
      }
    },
    color: String,
    primaryColor: String,
    secondaryColor: String,
    primaryOpacity: {
      type: [Number, String],
      default: 1
    },
    secondaryOpacity: {
      type: [Number, String],
      default: 0.4
    },
    // eslint-disable-next-line vue/require-prop-types
    swapOpacity: {
      default: false
    }
  },
  setup: function setup(props) {
    var i = function i() {
      var _props$icon$icon, _props$icon;

      return (_props$icon$icon = (_props$icon = props.icon) == null ? void 0 : _props$icon.icon) != null ? _props$icon$icon : [0, 0, '', [], ''];
    };

    return {
      i: vue.computed(i),
      style: vue.computed(function () {
        if (!i()[4]) {
          return {};
        }

        var base = {
          height: '1em',
          overflow: 'visible',
          verticalAlign: '-.125em'
        };
        var fw = props.fw,
            pull = props.pull,
            size = props.size;

        if (fw) {
          base.textAlign = 'center';
          base.width = '1.25em';
        }

        if (pull) {
          base.float = pull;
        }

        if (size) {
          if (size === 'lg') {
            base.fontSize = '1.33333em';
            base.lineHeight = '.75em';
            base.verticalAlign = '-.225em';
          } else if (size === 'xs') {
            base.fontSize = '.75em';
          } else if (size === 'sm') {
            base.fontSize = '.875em';
          } else {
            base.fontSize = size.replace('x', 'em');
          }
        }

        return base;
      }),
      transform: vue.computed(function () {
        var flip = props.flip,
            rotate = props.rotate;
        var transform = '';

        if (flip) {
          var flipX = 1;
          var flipY = 1;

          if (flip === 'horizontal') {
            flipX = -1;
          } else if (flip === 'vertical') {
            flipY = -1;
          } else {
            flipX = flipY = -1;
          }

          transform += " scale(" + flipX + " " + flipY + ")";
        }

        if (rotate) {
          transform += " rotate(" + rotate + " 0 0)";
        }

        return transform;
      })
    };
  }
});

var _hoisted_1 = {
  key: 0,
  transform: "translate(256 256)"
};
function render(_ctx, _cache, $props, $setup, $data, $options) {
  return vue.withDirectives((vue.openBlock(), vue.createBlock("svg", {
    viewBox: "0 0 " + _ctx.i[0] + " " + _ctx.i[1],
    style: _ctx.style,
    "aria-hidden": "true",
    role: "img",
    xmlns: "http://www.w3.org/2000/svg"
  }, [_ctx.i[4] ? (vue.openBlock(), vue.createBlock("g", _hoisted_1, [vue.createVNode("g", {
    transform: _ctx.transform
  }, [typeof _ctx.i[4] === 'string' ? (vue.openBlock(), vue.createBlock("path", {
    key: 0,
    d: _ctx.i[4],
    fill: _ctx.color || _ctx.primaryColor || 'currentColor',
    transform: "translate(-256 -256)"
  }, null, 8
  /* PROPS */
  , ["d", "fill"])) : (vue.openBlock(), vue.createBlock(vue.Fragment, {
    key: 1
  }, [vue.createVNode("path", {
    d: _ctx.i[4][0],
    fill: _ctx.secondaryColor || _ctx.color || 'currentColor',
    "fill-opacity": _ctx.swapOpacity !== false ? _ctx.primaryOpacity : _ctx.secondaryOpacity,
    transform: "translate(-256 -256)"
  }, null, 8
  /* PROPS */
  , ["d", "fill", "fill-opacity"]), vue.createVNode("path", {
    d: _ctx.i[4][1],
    fill: _ctx.primaryColor || _ctx.color || 'currentColor',
    "fill-opacity": _ctx.swapOpacity !== false ? _ctx.secondaryOpacity : _ctx.primaryOpacity,
    transform: "translate(-256 -256)"
  }, null, 8
  /* PROPS */
  , ["d", "fill", "fill-opacity"])], 64
  /* STABLE_FRAGMENT */
  ))], 8
  /* PROPS */
  , ["transform"])])) : vue.createCommentVNode("v-if", true)], 12
  /* STYLE, PROPS */
  , ["viewBox"])), [[vue.vShow, _ctx.i[4]]]);
}

script.render = render;
script.__file = "src/fa.vue";

module.exports = script;
